class Attribute:
    def __init__(self, key, value, dom, twoWay=False):
        self.key = key
        self.value = value
        self.dom = dom
        self.twoWay = twoWay

    def toDict(self):
        return {self.key: self.value}


from PyQt5.QtCore import Qt

ElementAlign = {
    'center': Qt.AlignCenter,
    'hcenter': Qt.AlignHCenter,
    'vcenter': Qt.AlignVCenter,
    'bottom': Qt.AlignBottom,
    'top': Qt.AlignTop,
    'right': Qt.AlignRight,
    'left': Qt.AlignLeft
}


from PyQt5.QtWidgets import QWidget, QMainWindow, QLabel

class Widget(QWidget):
    def showType(self, isFull):
        if isFull:
            return super().showFullScreen()
        else:
            return super().show()

class Window(QMainWindow, Widget):
    pass

class Label(QLabel):
    def setTextOrPixmap(self, data):
        if type(data) == str:
            self.setText(data)
        else:
            self.setPixmap(data)


from mvvmQt.Elements import Element

def __updateObValue(ob, v, t):
    if t == bool:
        ob.value = bool(v - 1)
    else:
        ob.value = v

def groupChecked(*params):
    v = params[0]
    o: Element = params[-2]
    ob = params[-1]

    attr = list(filter(lambda _: _.key == 'checked', o.attrs))[0]

    if attr.twoWay and not getattr(o.qt, '_bindClicked', False):
        o.qt.buttonClicked[int].connect(lambda id: __updateObValue(ob, id, type(v)))
        o.qt._bindClicked = True

    o.qt.buttons()[int(v)].setChecked(True)